@@ -1,8 +1,5 @@
 package Net::RackSpace::CloudServers;
-
-BEGIN {
-    $Net::RackSpace::CloudServers::VERSION = '0.14';
-}
+$Net::RackSpace::CloudServers::VERSION = '0.15';
 use warnings;
 use strict;
 use Any::Moose;
@@ -19,10 +16,10 @@ use Carp;
 
 our $DEBUG = 0;
 
-has 'user'    => ( is => 'ro', isa => 'Str', required => 1 );
-has 'key'     => ( is => 'ro', isa => 'Str', required => 1 );
-has 'timeout' => ( is => 'ro', isa => 'Num', required => 0, default => 30 );
-has 'ua' => ( is => 'rw', isa => 'LWP::UserAgent', required => 0 );
+has 'user'    => (is => 'ro', isa => 'Str', required => 1);
+has 'key'     => (is => 'ro', isa => 'Str', required => 1);
+has 'timeout' => (is => 'ro', isa => 'Num', required => 0, default => 30);
+has 'ua' => (is => 'rw', isa => 'LWP::UserAgent', required => 0);
 
 # This module currently supports only US and UK
 subtype ValidLocation => as 'Str' => where { $_ eq 'US' or $_ eq 'UK' };
@@ -36,7 +33,7 @@ our %api_endpoint_by_location = (
 # So this module can work on either the US or the UK versions
 # of the API, defaulting to the current default
 has 'location' =>
-  ( is => 'rw', isa => 'ValidLocation', required => 1, default => 'US' );
+    (is => 'rw', isa => 'ValidLocation', required => 1, default => 'US');
 
 has 'limits' => (
     is       => 'rw',
@@ -45,23 +42,14 @@ has 'limits' => (
     required => 1,
     default  => sub {
         my ($self) = @_;
-        return Net::RackSpace::CloudServers::Limits->new( cloudservers => $self,
+        return Net::RackSpace::CloudServers::Limits->new(cloudservers => $self,
         );
-    }
-);
+    });
 
-has 'server_management_url' => (
-    is       => 'rw',
-    isa      => 'Str',
-    required => 0,
-);
-has 'storage_url' => (
-    is       => 'rw',
-    isa      => 'Str',
-    required => 0,
-);
-has 'cdn_management_url' => ( is => 'rw', isa => 'Str', required => 0 );
-has 'token'              => ( is => 'rw', isa => 'Str', required => 0 );
+has 'server_management_url' => (is => 'rw', isa => 'Str', required => 0,);
+has 'storage_url'           => (is => 'rw', isa => 'Str', required => 0,);
+has 'cdn_management_url'    => (is => 'rw', isa => 'Str', required => 0);
+has 'token'                 => (is => 'rw', isa => 'Str', required => 0);
 
 no Any::Moose;
 __PACKAGE__->meta->make_immutable();
@@ -78,11 +66,10 @@ sub BUILD {
         LWP::ConnCache::MaxKeepAliveRequests->new(
             total_capacity          => 10,
             max_keep_alive_requests => 990,
-        )
-    );
+        ));
     my $http_codes_hr = $ua->codes_to_determinate();
     $http_codes_hr->{422} = 1;   # used by cloudfiles for upload data corruption
-    $ua->timeout( $self->timeout );
+    $ua->timeout($self->timeout);
     $ua->env_proxy;
     $self->ua($ua);
     $self->_authenticate;
@@ -93,21 +80,17 @@ sub _authenticate {
     my $request = HTTP::Request->new(
         'GET',
         $api_endpoint_by_location{ $self->location },
-        [
-            'X-Auth-User' => $self->user,
-            'X-Auth-Key'  => $self->key,
-        ]
-    );
+        ['X-Auth-User' => $self->user, 'X-Auth-Key' => $self->key,]);
     my $response = $self->_request($request);
     confess 'Unauthorized' if $response->code == 401;
     confess 'Unknown error ' . $response->code . "\n" . $response->content
-      if $response->code != 204;
+        if $response->code != 204;
 
     my $server_management_url = $response->header('X-Server-Management-Url')
-      || confess 'Missing server management url';
+        || confess 'Missing server management url';
     $self->server_management_url($server_management_url);
     my $token = $response->header('X-Auth-Token')
-      || confess 'Missing auth token';
+        || confess 'Missing auth token';
     $self->token($token);
 
     # From the docs:
@@ -116,17 +99,17 @@ sub _authenticate {
     # for purposes of interacting with Cloud Servers.
 
     my $storage_url = $response->header('X-Storage-Url')
-      || confess 'Missing storage url';
+        || confess 'Missing storage url';
     $self->storage_url($storage_url);
     my $cdn_management_url = $response->header('X-CDN-Management-Url')
-      || confess 'Missing CDN management url';
+        || confess 'Missing CDN management url';
     $self->storage_url($cdn_management_url);
 }
 
 sub _request {
-    my ( $self, $request, $filename ) = @_;
+    my ($self, $request, $filename) = @_;
     warn "Requesting ", $request->as_string if $DEBUG;
-    my $response = $self->ua->request( $request, $filename );
+    my $response = $self->ua->request($request, $filename);
     warn "Requested, got ", $response->as_string if $DEBUG;
 
     # From the docs:
@@ -134,7 +117,7 @@ sub _request {
     # Applications should be designed to re-authenticate after
     # receiving a 401 Unauthorized response.
 
-    if ( $response->code == 401 && $request->header('X-Auth-Token') ) {
+    if ($response->code == 401 && $request->header('X-Auth-Token')) {
 
         # http://trac.cyberduck.ch/ticket/2876
         # Be warned that the token will expire over time (possibly as short
@@ -143,10 +126,10 @@ sub _request {
         # and then re-authenticate to obtain an updated token.
         warn "Need reauthentication" if $DEBUG;
         $self->_authenticate;
-        $request->header( 'X-Auth-Token', $self->token );
+        $request->header('X-Auth-Token', $self->token);
         warn $request->as_string if $DEBUG;
         warn "Re-requesting" if $DEBUG;
-        $response = $self->ua->request( $request, $filename );
+        $response = $self->ua->request($request, $filename);
         warn $response->as_string if $DEBUG;
     }
 
@@ -155,16 +138,16 @@ sub _request {
     # a 413 Rate Control HTTP response will be returned with a
     # Reply-After header to notify the client when they can attempt to
     # try again.
-    if ( $response->code == 413 ) {
+    if ($response->code == 413) {
         my $when = $response->header('Reply-After');
-        if ( !defined $when ) {
+        if (!defined $when) {
             $when = 'in about 10 mins';
         }
         else {
             $when = 'at ' . $when;
         }
         confess "Cannot execute request as rate control limit exceeded; retry ",
-          $when;
+            $when;
     }
 
     return $response;
@@ -174,34 +157,35 @@ sub get_server {
     my $self   = shift;
     my $id     = shift;
     my $detail = shift;
-    my $uri    = (
-          ( defined $detail && $detail )
-        ? ( defined $id ? '/servers/' . $id : '/servers/detail' )
-        : ( defined $id ? '/servers/' . $id : '/servers' )
-    );
+    my $uri =
+        ( (defined $detail && $detail)
+        ? (defined $id ? '/servers/' . $id : '/servers/detail')
+        : (defined $id ? '/servers/' . $id : '/servers'));
+
+    # cache-bust
+    $uri .= sprintf '?test=%s.%s', time, rand;
     my $request = HTTP::Request->new(
         'GET',
         $self->server_management_url . $uri,
-        [ 'X-Auth-Token' => $self->token ]
-    );
+        ['X-Auth-Token' => $self->token]);
     my $response = $self->_request($request);
-    return if scalar grep { $response->code eq $_ } ( 204, 404 );
+    return if scalar grep { $response->code eq $_ } (204, 404);
     confess 'Unknown error' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 203 );
+        unless scalar grep { $response->code eq $_ } (200, 203);
     my @servers;
-    my $hash_response = from_json( $response->content );
+    my $hash_response = from_json($response->content);
     warn Dump($hash_response) if $DEBUG;
 
     # {"servers":[{"name":"test00","id":12345}]}
 
     confess 'response does not contain key "servers"'
-      if ( !defined $id && !defined $hash_response->{servers} );
+        if (!defined $id && !defined $hash_response->{servers});
     confess 'response does not contain key "server"'
-      if ( defined $id && !defined $hash_response->{server} );
+        if (defined $id && !defined $hash_response->{server});
     confess 'response does not contain arrayref of "servers"'
-      if ( !defined $id && ref $hash_response->{servers} ne 'ARRAY' );
+        if (!defined $id && ref $hash_response->{servers} ne 'ARRAY');
     confess 'response does not contain hashref of "server"'
-      if ( defined $id && ref $hash_response->{server} ne 'HASH' );
+        if (defined $id && ref $hash_response->{server} ne 'HASH');
 
     return map {
         Net::RackSpace::CloudServers::Server->new(
@@ -218,8 +202,8 @@ sub get_server {
             private_address => $_->{addresses}->{private},
             metadata        => $_->{metadata},
             adminpass       => $_->{adminPass},
-          )
-    } @{ $hash_response->{servers} } if ( !defined $id );
+            )
+    } @{ $hash_response->{servers} } if (!defined $id);
 
     my $hserver = $hash_response->{server};
     return Net::RackSpace::CloudServers::Server->new(
@@ -234,45 +218,42 @@ sub get_server {
         public_address  => $hserver->{addresses}->{public},
         private_address => $hserver->{addresses}->{private},
         metadata        => $hserver->{metadata},
-        adminpass       => $hserver->{adminPass}
-    );
+        adminpass       => $hserver->{adminPass});
 }
 
 sub get_server_detail {
     my $self = shift;
     my $id   = shift;
-    return $self->get_server( $id, 1 );
+    return $self->get_server($id, 1);
 }
 
 sub get_flavor {
     my $self   = shift;
     my $id     = shift;
     my $detail = shift;
-    my $uri    = (
-          ( defined $detail && $detail )
-        ? ( defined $id ? '/flavors/' . $id : '/flavors/detail' )
-        : ( defined $id ? '/flavors/' . $id : '/flavors' )
-    );
+    my $uri =
+        ( (defined $detail && $detail)
+        ? (defined $id ? '/flavors/' . $id : '/flavors/detail')
+        : (defined $id ? '/flavors/' . $id : '/flavors'));
     my $request = HTTP::Request->new(
         'GET',
         $self->server_management_url . $uri,
-        [ 'X-Auth-Token' => $self->token ]
-    );
+        ['X-Auth-Token' => $self->token]);
     my $response = $self->_request($request);
     return if $response->code == 204;
     confess 'Unknown error ' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 203 );
-    my $hash_response = from_json( $response->content );
+        unless scalar grep { $response->code eq $_ } (200, 203);
+    my $hash_response = from_json($response->content);
     warn Dump($hash_response) if $DEBUG;
 
     confess 'response does not contain key "flavors"'
-      if ( !defined $id && !defined $hash_response->{flavors} );
+        if (!defined $id && !defined $hash_response->{flavors});
     confess 'response does not contain key "flavor"'
-      if ( defined $id && !defined $hash_response->{flavor} );
+        if (defined $id && !defined $hash_response->{flavor});
     confess 'response does not contain arrayref of "flavors"'
-      if ( !defined $id && ref $hash_response->{flavors} ne 'ARRAY' );
+        if (!defined $id && ref $hash_response->{flavors} ne 'ARRAY');
     confess 'response does not contain hashref of "flavor"'
-      if ( defined $id && ref $hash_response->{flavor} ne 'HASH' );
+        if (defined $id && ref $hash_response->{flavor} ne 'HASH');
 
     return map {
         Net::RackSpace::CloudServers::Flavor->new(
@@ -281,8 +262,8 @@ sub get_flavor {
             name         => $_->{name},
             ram          => $_->{ram},
             disk         => $_->{disk},
-          )
-    } @{ $hash_response->{flavors} } if ( !defined $id );
+            )
+    } @{ $hash_response->{flavors} } if (!defined $id);
     return Net::RackSpace::CloudServers::Flavor->new(
         cloudservers => $self,
         id           => $hash_response->{flavor}->{id},
@@ -295,39 +276,37 @@ sub get_flavor {
 sub get_flavor_detail {
     my $self = shift;
     my $id   = shift;
-    return $self->get_flavor( $id, 1 );
+    return $self->get_flavor($id, 1);
 }
 
 sub get_image {
     my $self   = shift;
     my $id     = shift;
     my $detail = shift;
-    my $uri    = (
-          ( defined $detail && $detail )
-        ? ( defined $id ? '/images/' . $id : '/images/detail' )
-        : ( defined $id ? '/images/' . $id : '/images' )
-    );
+    my $uri =
+        ( (defined $detail && $detail)
+        ? (defined $id ? '/images/' . $id : '/images/detail')
+        : (defined $id ? '/images/' . $id : '/images'));
     $uri .= '?changes_since=0';
     my $request = HTTP::Request->new(
         'GET',
         $self->server_management_url . $uri,
-        [ 'X-Auth-Token' => $self->token ]
-    );
+        ['X-Auth-Token' => $self->token]);
     my $response = $self->_request($request);
     return if $response->code == 204;
     confess 'Unknown error' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 203 );
-    my $hash_response = from_json( $response->content );
+        unless scalar grep { $response->code eq $_ } (200, 203);
+    my $hash_response = from_json($response->content);
     warn Dump($hash_response) if $DEBUG;
 
     confess 'response does not contain key "images"'
-      if ( !defined $id && !defined $hash_response->{images} );
+        if (!defined $id && !defined $hash_response->{images});
     confess 'response does not contain key "image"'
-      if ( defined $id && !defined $hash_response->{image} );
+        if (defined $id && !defined $hash_response->{image});
     confess 'response does not contain arrayref of "images"'
-      if ( !defined $id && ref $hash_response->{images} ne 'ARRAY' );
+        if (!defined $id && ref $hash_response->{images} ne 'ARRAY');
     confess 'response does not contain hashref of "image"'
-      if ( defined $id && ref $hash_response->{image} ne 'HASH' );
+        if (defined $id && ref $hash_response->{image} ne 'HASH');
 
     return map {
         Net::RackSpace::CloudServers::Image->new(
@@ -339,8 +318,8 @@ sub get_image {
             created      => $_->{created},
             status       => $_->{status},
             progress     => $_->{progress},
-          )
-    } @{ $hash_response->{images} } if ( !defined $id );
+            )
+    } @{ $hash_response->{images} } if (!defined $id);
     return Net::RackSpace::CloudServers::Image->new(
         cloudservers => $self,
         id           => $hash_response->{image}->{id},
@@ -356,7 +335,7 @@ sub get_image {
 sub get_image_detail {
     my $self = shift;
     my $id   = shift;
-    return $self->get_image( $id, 1 );
+    return $self->get_image($id, 1);
 }
 
 sub delete_image {
@@ -365,24 +344,27 @@ sub delete_image {
     my $request = HTTP::Request->new(
         'DELETE',
         $self->server_management_url . '/images/' . $id,
-        [
-            'X-Auth-Token' => $self->token,
-            'Content-Type' => 'application/json',
-        ],
+        ['X-Auth-Token' => $self->token, 'Content-Type' => 'application/json',],
     );
     my $response = $self->_request($request);
     confess 'Unknown error' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 204 );
+        unless scalar grep { $response->code eq $_ } (200, 204);
     return;
 }
 
+1;
+
+__END__
+
+=encoding utf-8
+
 =head1 NAME
 
 Net::RackSpace::CloudServers - Interface to RackSpace CloudServers via API
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -529,5 +511,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
-1;    # End of Net::RackSpace::CloudServers
