@@ -1,30 +1,31 @@
 package Net::RackSpace::CloudServers::Flavor;
-
-BEGIN {
-    $Net::RackSpace::CloudServers::Flavor::VERSION = '0.14';
-}
+$Net::RackSpace::CloudServers::Flavor::VERSION = '0.15';
 use warnings;
 use strict;
 use Any::Moose;
 use Carp;
 
 has 'cloudservers' =>
-  ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
-has 'id'   => ( is => 'ro', isa => 'Int',        required => 1 );
-has 'name' => ( is => 'ro', isa => 'Str',        required => 1 );
-has 'ram'  => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
-has 'disk' => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
+    (is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1);
+has 'id'   => (is => 'ro', isa => 'Int',        required => 1);
+has 'name' => (is => 'ro', isa => 'Str',        required => 1);
+has 'ram'  => (is => 'ro', isa => 'Maybe[Int]', required => 1);
+has 'disk' => (is => 'ro', isa => 'Maybe[Int]', required => 1);
 
 no Any::Moose;
 __PACKAGE__->meta->make_immutable();
 
+1;
+
+__END__
+
 =head1 NAME
 
 Net::RackSpace::CloudServers::Flavor - a RackSpace CloudServers Flavor
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -124,5 +125,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
-1;    # End of Net::RackSpace::CloudServers::Flavor
