@@ -1,33 +1,34 @@
 package Net::RackSpace::CloudServers::Image;
-
-BEGIN {
-    $Net::RackSpace::CloudServers::Image::VERSION = '0.14';
-}
+$Net::RackSpace::CloudServers::Image::VERSION = '0.15';
 use warnings;
 use strict;
 use Any::Moose;
 use Carp;
 
 has 'cloudservers' =>
-  ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
-has 'id'       => ( is => 'ro', isa => 'Int',        required => 1 );
-has 'name'     => ( is => 'ro', isa => 'Str',        required => 1 );
-has 'serverid' => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
-has 'updated'  => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
-has 'created'  => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
-has 'status'   => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
-has 'progress' => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
+    (is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1);
+has 'id'       => (is => 'ro', isa => 'Int',        required => 1);
+has 'name'     => (is => 'ro', isa => 'Str',        required => 1);
+has 'serverid' => (is => 'ro', isa => 'Maybe[Int]', required => 1);
+has 'updated'  => (is => 'ro', isa => 'Maybe[Str]', required => 1);
+has 'created'  => (is => 'ro', isa => 'Maybe[Str]', required => 1);
+has 'status'   => (is => 'ro', isa => 'Maybe[Str]', required => 1);
+has 'progress' => (is => 'ro', isa => 'Maybe[Int]', required => 1);
 
 no Any::Moose;
 __PACKAGE__->meta->make_immutable();
 
+1;
+
+__END__
+
 =head1 NAME
 
 Net::RackSpace::CloudServers::Image - a RackSpace CloudServers Image
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -140,5 +141,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
-1;    # End of Net::RackSpace::CloudServers::Image
