@@ -1,8 +1,5 @@
 package Net::RackSpace::CloudServers::Limits;
-
-BEGIN {
-    $Net::RackSpace::CloudServers::Limits::VERSION = '0.14';
-}
+$Net::RackSpace::CloudServers::Limits::VERSION = '0.15';
 use warnings;
 use strict;
 our $DEBUG = 0;
@@ -13,11 +10,11 @@ use YAML;
 use Carp;
 
 has 'cloudservers' =>
-  ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
-has 'totalramsize'      => ( is => 'rw', isa => 'Int', );
-has 'maxipgroups'       => ( is => 'rw', isa => 'Int', );
-has 'maxipgroupmembers' => ( is => 'rw', isa => 'Int', );
-has 'rate'              => ( is => 'rw', isa => 'Maybe[ArrayRef]', );
+    (is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1);
+has 'totalramsize'      => (is => 'rw', isa => 'Int',);
+has 'maxipgroups'       => (is => 'rw', isa => 'Int',);
+has 'maxipgroupmembers' => (is => 'rw', isa => 'Int',);
+has 'rate'              => (is => 'rw', isa => 'Maybe[ArrayRef]',);
 
 no Any::Moose;
 __PACKAGE__->meta->make_immutable();
@@ -32,54 +29,56 @@ sub refresh {
     my $request = HTTP::Request->new(
         'GET',
         $self->cloudservers->server_management_url . '/limits',
-        [ 'X-Auth-Token' => $self->cloudservers->token ]
-    );
+        ['X-Auth-Token' => $self->cloudservers->token]);
     my $response = $self->cloudservers->_request($request);
     return if $response->code == 204;
     confess 'Unknown error ' . $response->code
-      unless scalar grep { $response->code eq $_ } ( 200, 203 );
-    my $hr = from_json( $response->content );
+        unless scalar grep { $response->code eq $_ } (200, 203);
+    my $hr = from_json($response->content);
     warn Dump($hr) if $DEBUG;
 
 #{"limits":{"absolute":{"maxTotalRAMSize":51200,"maxIPGroupMembers":25,"maxNumServers":25,"maxIPGroups":25},"rate":[{"value":50,"unit":"DAY","verb":"POST","remaining":50,"URI":"\/servers*","resetTime":1247769469,"regex":"^\/servers"},{"value":10,"unit":"MINUTE","verb":"POST","remaining":10,"URI":"*","resetTime":1247769469,"regex":".*"},{"value":600,"unit":"MINUTE","verb":"DELETE","remaining":600,"URI":"*","resetTime":1247769469,"regex":".*"},{"value":10,"unit":"MINUTE","verb":"PUT","remaining":10,"URI":"*","resetTime":1247769469,"regex":".*"},{"value":3,"unit":"MINUTE","verb":"GET","remaining":3,"URI":"*changes-since*","resetTime":1247769469,"regex":"changes-since"}]}}
     confess 'response does not contain key "limits"'
-      unless defined $hr->{limits};
+        unless defined $hr->{limits};
     confess 'response does not contain hashref of "limits"'
-      unless ( ref $hr->{limits} eq 'HASH' );
+        unless (ref $hr->{limits} eq 'HASH');
 
     confess 'response "limits" does not contain key "rate"'
-      unless defined $hr->{limits}->{rate};
+        unless defined $hr->{limits}->{rate};
     confess 'response "limits", key "rate" is not an arrayref'
-      unless ( ref $hr->{limits}->{rate} eq 'ARRAY' );
-    $self->rate( $hr->{limits}->{rate} );
+        unless (ref $hr->{limits}->{rate} eq 'ARRAY');
+    $self->rate($hr->{limits}->{rate});
 
     confess 'response "limits" does not contain key "absolute"'
-      unless defined $hr->{limits}->{absolute};
+        unless defined $hr->{limits}->{absolute};
     confess 'response "limits", key "absolute" is not an hashref'
-      unless ( ref $hr->{limits}->{absolute} eq 'HASH' );
+        unless (ref $hr->{limits}->{absolute} eq 'HASH');
     confess
-      'response "limits", key "absolute" does not contain key "maxTotalRAMSize"'
-      unless ( defined $hr->{limits}->{absolute}->{"maxTotalRAMSize"} );
-    $self->totalramsize( $hr->{limits}->{absolute}->{"maxTotalRAMSize"} );
+        'response "limits", key "absolute" does not contain key "maxTotalRAMSize"'
+        unless (defined $hr->{limits}->{absolute}->{"maxTotalRAMSize"});
+    $self->totalramsize($hr->{limits}->{absolute}->{"maxTotalRAMSize"});
     confess
-      'response "limits", key "absolute" does not contain key "maxIPGroups"'
-      unless ( defined $hr->{limits}->{absolute}->{"maxIPGroups"} );
-    $self->maxipgroups( $hr->{limits}->{absolute}->{"maxIPGroups"} );
+        'response "limits", key "absolute" does not contain key "maxIPGroups"'
+        unless (defined $hr->{limits}->{absolute}->{"maxIPGroups"});
+    $self->maxipgroups($hr->{limits}->{absolute}->{"maxIPGroups"});
     confess
-'response "limits", key "absolute" does not contain key "maxIPGroupMembers"'
-      unless ( defined $hr->{limits}->{absolute}->{"maxIPGroupMembers"} );
-    $self->maxipgroupmembers(
-        $hr->{limits}->{absolute}->{"maxIPGroupMembers"} );
+        'response "limits", key "absolute" does not contain key "maxIPGroupMembers"'
+        unless (defined $hr->{limits}->{absolute}->{"maxIPGroupMembers"});
+    $self->maxipgroupmembers($hr->{limits}->{absolute}->{"maxIPGroupMembers"});
     return $self;
 }
 
+1;
+
+__END__
+
 =head1 NAME
 
 Net::RackSpace::CloudServers::Limits - a RackSpace CloudServers Limits instance
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -184,5 +183,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
-1;    # End of Net::RackSpace::CloudServers::Limits
