@@ -1,8 +1,5 @@
 package Net::RackSpace::CloudServers::Server;
-
-BEGIN {
-    $Net::RackSpace::CloudServers::Server::VERSION = '0.14';
-}
+$Net::RackSpace::CloudServers::Server::VERSION = '0.15';
 use warnings;
 use strict;
 our $DEBUG = 0;
@@ -14,19 +11,19 @@ use Net::RackSpace::CloudServers::Image;
 use Carp;
 
 has 'cloudservers' =>
-  ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
-has 'id' => ( is => 'ro', isa => 'Int', required => 1, default => 0 );
-has 'name'     => ( is => 'ro', isa => 'Str',        required => 1 );
-has 'imageid'  => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
-has 'flavorid' => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
+    (is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1);
+has 'id' => (is => 'ro', isa => 'Int', required => 1, default => 0);
+has 'name'     => (is => 'ro', isa => 'Str',        required => 1);
+has 'imageid'  => (is => 'ro', isa => 'Maybe[Int]', required => 1);
+has 'flavorid' => (is => 'ro', isa => 'Maybe[Int]', required => 1);
 has 'hostid' =>
-  ( is => 'ro', isa => 'Maybe[Str]', required => 1, default => undef );
+    (is => 'ro', isa => 'Maybe[Str]', required => 1, default => undef);
 has 'status' =>
-  ( is => 'ro', isa => 'Maybe[Str]', required => 1, default => undef );
+    (is => 'ro', isa => 'Maybe[Str]', required => 1, default => undef);
 has 'adminpass' =>
-  ( is => 'ro', isa => 'Maybe[Str]', required => 1, default => undef );
+    (is => 'ro', isa => 'Maybe[Str]', required => 1, default => undef);
 has 'progress' =>
-  ( is => 'ro', isa => 'Maybe[Str]', required => 1, default => undef );
+    (is => 'ro', isa => 'Maybe[Str]', required => 1, default => undef);
 has 'public_address' => (
     is       => 'ro',
     isa      => 'Maybe[ArrayRef[Str]]',
@@ -40,9 +37,9 @@ has 'private_address' => (
     default  => undef
 );
 has 'metadata' =>
-  ( is => 'ro', isa => 'Maybe[HashRef]', required => 1, default => undef );
+    (is => 'ro', isa => 'Maybe[HashRef]', required => 1, default => undef);
 has 'personality' =>
-  ( is => 'ro', isa => 'Maybe[ArrayRef]', required => 1, default => undef );
+    (is => 'ro', isa => 'Maybe[ArrayRef]', required => 1, default => undef);
 
 no Any::Moose;
 __PACKAGE__->meta->make_immutable();
@@ -58,8 +55,7 @@ sub change_root_password {
             'X-Auth-Token' => $self->cloudservers->token,
             'Content-Type' => 'application/json',
         ],
-        to_json( { server => { adminPass => $password, } } )
-    );
+        to_json({ server => { adminPass => $password, } }));
     my $response = $self->cloudservers->_request($request);
     confess 'Unknown error' if $response->code != 202;
     return $response;
@@ -76,8 +72,7 @@ sub change_name {
             'X-Auth-Token' => $self->cloudservers->token,
             'Content-Type' => 'application/json',
         ],
-        to_json( { server => { name => $name, } } )
-    );
+        to_json({ server => { name => $name, } }));
     my $response = $self->cloudservers->_request($request);
     confess 'Unknown error' if $response->code != 202;
     return $response;
@@ -108,22 +103,14 @@ sub create_image {
             'X-Auth-Token' => $self->cloudservers->token,
             'Content-Type' => 'application/json',
         ],
-        to_json(
-            {
-                image => {
-                    serverId => $self->id,
-                    name     => $imgname,
-                }
-            }
-        )
-    );
+        to_json({ image => { serverId => $self->id, name => $imgname, } }));
     my $response = $self->cloudservers->_request($request);
-    if ( $response->code != 202 ) {
+    if ($response->code != 202) {
         confess 'Unknown error ' . $response->code, "\n",
-          Dump( $response->content );
+            Dump($response->content);
     }
-    my $hash_response = from_json( $response->content );
-    if ( !defined $hash_response->{image} ) {
+    my $hash_response = from_json($response->content);
+    if (!defined $hash_response->{image}) {
         confess 'response does not contain "image":', Dump($hash_response);
     }
     return Net::RackSpace::CloudServers::Image->new(
@@ -147,29 +134,25 @@ sub create_server {
             'X-Auth-Token' => $self->cloudservers->token,
             'Content-Type' => 'application/json',
         ],
-        to_json(
-            {
+        to_json({
                 server => {
                     name     => $self->name,
                     imageId  => int $self->imageid,
                     flavorId => int $self->flavorid,
-                    defined $self->metadata ? ( metadata => $self->metadata )
+                    defined $self->metadata ? (metadata => $self->metadata)
                     : (),
                     defined $self->personality
-                    ? ( personality => $self->personality )
+                    ? (personality => $self->personality)
                     : (),
-                }
-            }
-        )
-    );
+                } }));
     my $response = $self->cloudservers->_request($request);
     confess 'Unknown error' if $response->code != 202;
-    my $hash_response = from_json( $response->content );
+    my $hash_response = from_json($response->content);
     warn Dump($hash_response) if $DEBUG;
     confess 'response does not contain key "server"'
-      if ( !defined $hash_response->{server} );
+        if (!defined $hash_response->{server});
     confess 'response does not contain hashref of "server"'
-      if ( ref $hash_response->{server} ne 'HASH' );
+        if (ref $hash_response->{server} ne 'HASH');
     my $hserver = $hash_response->{server};
     return __PACKAGE__->new(
         cloudservers    => $self->cloudservers,
@@ -188,13 +171,17 @@ sub create_server {
     );
 }
 
+1;
+
+__END__
+
 =head1 NAME
 
 Net::RackSpace::CloudServers::Server - a RackSpace CloudServers Server instance
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -219,9 +206,9 @@ version 0.14
   }
 
   ## Create server from template
-  my $tmp = Net::Rackspace::CloudServer::Server->new(
+  my $tmp = Net::RackSpace::CloudServer::Server->new(
     cloudservers => $cs, name => 'myserver',
-    flavor => 2, image => 8,
+    flavorid => 2, imageid => 8,
     # others
   );
   my $srv = $tmp->create_server;
@@ -362,5 +349,3 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
-1;    # End of Net::RackSpace::CloudServers::Server
